@@ -8,9 +8,9 @@ pub struct Session {
   pub id:       String,
   pub name:     String,
   pub node:     Option<String>,
-  pub lock_delay: String,
-  pub behavior:  String,
-  pub ttl:      String,
+  pub LockDelay: String,
+  pub Behavior:  String,
+  pub TTL:      String,
   pub node_checks:  Vec<String>,
   service_checks: Option<String>,
   create_index:   u32,
@@ -29,9 +29,9 @@ impl Session {
       id: "".to_string(),
       name: "".to_string(),
       node: None,
-      lock_delay: "".to_string(),
-      behavior: "".to_string(),
-      ttl: "".to_string(),
+      LockDelay: "".to_string(),
+      Behavior: "".to_string(),
+      TTL: "".to_string(),
       node_checks: vec![],
       service_checks: None,
       create_index: 0,
@@ -42,7 +42,7 @@ impl Session {
   pub fn set(&self, c: &Client, s: &Session) -> String {
     let url = format!("http://{}:{}/v1/session/create", c.host, c.port);
     let payload = serde_json::to_string(s).unwrap();
-    c.debug_print(format!("set session payload ------ {}", payload).as_str());
+    c.debug_print(format!("set session payload ------ {}", payload).as_str(), );
     let mut rsp = reqwest::Client::new()
       .put(&url)
       .body(payload)
@@ -52,7 +52,7 @@ impl Session {
     // rsp.read_to_string(&mut body).map_err( |e| e.to_string());
     // c.debug_print(format!("session set: {:?}", body).as_str());
     let session_set: SessionSet = rsp.json().unwrap();
-    c.debug_print(format!("session set: {:?}", session_set).as_str());
+    c.debug_print(format!("session set: {:?}", session_set).as_str(), );
     session_set.ID
   }
 
@@ -71,6 +71,18 @@ impl Session {
       Err(CustomError(format!("renew session err: {}", sid)))
     }
   }
+
+  pub fn delete(&self, c: &Client, sid: &str) -> String {
+    let url = format!("http://{}:{}/v1/session/destroy/{}", c.host, c.port, sid);
+    let mut rsp = reqwest::Client::new()
+      .put(&url)
+      .send()
+      .map_err( |e| e.to_string()).unwrap();
+    let mut body = String::new();
+    rsp.read_to_string(&mut body).map_err( |e| e.to_string() );
+    c.debug_print(format!("session delete return ---- {}", body).as_str());
+    body
+  }
 }
 
 
